@@ -11,7 +11,7 @@
   +--------------------------------------------------------------------+
 */
 
-/* $Id: gnupg.c 330830 2013-07-09 13:09:18Z remi $ */
+/* $Id: gnupg.c 335919 2015-02-11 18:10:16Z jimjag $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -136,12 +136,15 @@ static void gnupg_res_dtor(zend_rsrc_list_entry *rsrc TSRMLS_DC) {
 static void gnupg_res_init(gnupg_object *intern TSRMLS_DC){
 	/* init the gpgme-lib and set the default values */
 	gpgme_ctx_t	ctx;
+	gpgme_error_t err;
 	gpgme_check_version			(NULL);
-	gpgme_new					(&ctx);
+	err =						gpgme_new(&ctx);
+	if(err == GPG_ERR_NO_ERROR) {
 #ifdef GNUPG_PATH
-	gpgme_ctx_set_engine_info(ctx, GPGME_PROTOCOL_OpenPGP, GNUPG_PATH, NULL);
+		gpgme_ctx_set_engine_info(ctx, GPGME_PROTOCOL_OpenPGP, GNUPG_PATH, NULL);
 #endif
-	gpgme_set_armor				(ctx,1);
+		gpgme_set_armor				(ctx,1);
+	}
 	intern->ctx				=	ctx;
 	intern->encryptkeys		=	NULL;
 	intern->encrypt_size	=	0;
@@ -1307,7 +1310,6 @@ PHP_FUNCTION(gnupg_decryptverify){
 	if(!verify_result->signatures){
         GNUPG_ERR           ("no signature found");
 		gpgme_data_release(in);
-		free(out);
         return;
     }
 	gnupg_fetchsignatures   (verify_result->signatures, return_value);
@@ -1389,7 +1391,10 @@ PHP_FUNCTION(gnupg_import){
 	}
 	gpgme_data_release(in);
 	result = gpgme_op_import_result (intern->ctx);
-
+	
+	if(result->imports->result != GPG_ERR_NO_ERROR){
+		RETURN_FALSE;
+	}
 	array_init				(return_value);
     add_assoc_long          (return_value,  "imported",     	result->imported);
 	add_assoc_long			(return_value,	"unchanged",		result->unchanged);
